@@ -9,8 +9,9 @@ import (
 
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
+	pconstants "github.com/turbot/pipe-fittings/constants"
+	"github.com/turbot/pipe-fittings/pipes"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
-	"github.com/turbot/steampipe/pkg/cloud"
 	"github.com/turbot/steampipe/pkg/cmdconfig"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/error_helpers"
@@ -28,7 +29,7 @@ func loginCmd() *cobra.Command {
 
 	cmdconfig.OnCmd(cmd).
 		AddCloudFlags().
-		AddBoolFlag(constants.ArgHelp, false, "Help for dashboard", cmdconfig.FlagOptions.WithShortHand("h"))
+		AddBoolFlag(pconstants.ArgHelp, false, "Help for dashboard", cmdconfig.FlagOptions.WithShortHand("h"))
 
 	return cmd
 }
@@ -36,10 +37,10 @@ func loginCmd() *cobra.Command {
 func runLoginCmd(cmd *cobra.Command, _ []string) {
 	ctx := cmd.Context()
 
-	log.Printf("[TRACE] login, pipes host %s", viper.Get(constants.ArgPipesHost))
+	log.Printf("[TRACE] login, pipes host %s", viper.Get(pconstants.ArgPipesHost))
 	log.Printf("[TRACE] opening login web page")
 	// start login flow - this will open a web page prompting user to login, and will give the user a code to enter
-	var id, err = cloud.WebLogin(ctx)
+	var id, err = pipes.WebLogin(ctx)
 	if err != nil {
 		error_helpers.ShowError(ctx, err)
 		exitCode = constants.ExitCodeLoginCloudConnectionFailed
@@ -54,7 +55,7 @@ func runLoginCmd(cmd *cobra.Command, _ []string) {
 	}
 
 	// save token
-	err = cloud.SaveToken(token)
+	err = pipes.SaveToken(token)
 	if err != nil {
 		error_helpers.ShowError(ctx, err)
 		exitCode = constants.ExitCodeLoginCloudConnectionFailed
@@ -76,7 +77,7 @@ func getToken(ctx context.Context, id string) (loginToken string, err error) {
 		if code != "" {
 			log.Printf("[TRACE] get login token")
 			// use this code to get a login token and store it
-			loginToken, err = cloud.GetLoginToken(ctx, id, code)
+			loginToken, err = pipes.GetLoginToken(ctx, id, code)
 			if err == nil {
 				return loginToken, nil
 			}
@@ -100,11 +101,11 @@ func getToken(ctx context.Context, id string) (loginToken string, err error) {
 }
 
 func displayLoginMessage(ctx context.Context, token string) {
-	userName, err := cloud.GetUserName(ctx, token)
+	userName, err := pipes.GetUserName(ctx, token)
 	error_helpers.FailOnError(sperr.WrapWithMessage(err, "failed to read user name"))
 
 	fmt.Println()
-	fmt.Printf("Logged in as: %s\n", constants.Bold(userName))
+	fmt.Printf("Logged in as: %s\n", pconstants.Bold(userName))
 	fmt.Println()
 }
 
