@@ -13,21 +13,24 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/helpers"
+	pconstants "github.com/turbot/pipe-fittings/constants"
+	"github.com/turbot/pipe-fittings/contexthelpers"
+	perror_helpers "github.com/turbot/pipe-fittings/error_helpers"
+	putils "github.com/turbot/pipe-fittings/ociinstaller"
+	pplugin "github.com/turbot/pipe-fittings/plugin"
+	"github.com/turbot/pipe-fittings/querydisplay"
+	"github.com/turbot/pipe-fittings/utils"
+	"github.com/turbot/pipe-fittings/versionfile"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 	"github.com/turbot/steampipe/pkg/cmdconfig"
 	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/contexthelpers"
 	"github.com/turbot/steampipe/pkg/db/db_local"
-	"github.com/turbot/steampipe/pkg/display"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/installationstate"
 	"github.com/turbot/steampipe/pkg/ociinstaller"
-	"github.com/turbot/steampipe/pkg/ociinstaller/versionfile"
 	"github.com/turbot/steampipe/pkg/plugin"
 	"github.com/turbot/steampipe/pkg/statushooks"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
-	"github.com/turbot/steampipe/pkg/utils"
 )
 
 type installedPlugin struct {
@@ -75,14 +78,14 @@ Examples:
 		PersistentPostRun: func(cmd *cobra.Command, args []string) {
 			utils.LogTime("cmd.plugin.PersistentPostRun start")
 			defer utils.LogTime("cmd.plugin.PersistentPostRun end")
-			plugin.CleanupOldTmpDirs(cmd.Context())
+			pplugin.CleanupOldTmpDirs(cmd.Context())
 		},
 	}
 	cmd.AddCommand(pluginInstallCmd())
 	cmd.AddCommand(pluginListCmd())
 	cmd.AddCommand(pluginUninstallCmd())
 	cmd.AddCommand(pluginUpdateCmd())
-	cmd.Flags().BoolP(constants.ArgHelp, "h", false, "Help for plugin")
+	cmd.Flags().BoolP(pconstants.ArgHelp, "h", false, "Help for plugin")
 
 	return cmd
 }
@@ -121,9 +124,9 @@ Examples:
 
 	cmdconfig.
 		OnCmd(cmd).
-		AddBoolFlag(constants.ArgProgress, true, "Display installation progress").
-		AddBoolFlag(constants.ArgSkipConfig, false, "Skip creating the default config file for plugin").
-		AddBoolFlag(constants.ArgHelp, false, "Help for plugin install", cmdconfig.FlagOptions.WithShortHand("h"))
+		AddBoolFlag(pconstants.ArgProgress, true, "Display installation progress").
+		AddBoolFlag(pconstants.ArgSkipConfig, false, "Skip creating the default config file for plugin").
+		AddBoolFlag(pconstants.ArgHelp, false, "Help for plugin install", cmdconfig.FlagOptions.WithShortHand("h"))
 	return cmd
 }
 
@@ -155,9 +158,9 @@ Examples:
 
 	cmdconfig.
 		OnCmd(cmd).
-		AddBoolFlag(constants.ArgAll, false, "Update all plugins to its latest available version").
-		AddBoolFlag(constants.ArgProgress, true, "Display installation progress").
-		AddBoolFlag(constants.ArgHelp, false, "Help for plugin update", cmdconfig.FlagOptions.WithShortHand("h"))
+		AddBoolFlag(pconstants.ArgAll, false, "Update all plugins to its latest available version").
+		AddBoolFlag(pconstants.ArgProgress, true, "Display installation progress").
+		AddBoolFlag(pconstants.ArgHelp, false, "Help for plugin update", cmdconfig.FlagOptions.WithShortHand("h"))
 
 	return cmd
 }
@@ -188,8 +191,8 @@ Examples:
 	cmdconfig.
 		OnCmd(cmd).
 		AddBoolFlag("outdated", false, "Check each plugin in the list for updates").
-		AddStringFlag(constants.ArgOutput, "table", "Output format: table or json").
-		AddBoolFlag(constants.ArgHelp, false, "Help for plugin list", cmdconfig.FlagOptions.WithShortHand("h"))
+		AddStringFlag(pconstants.ArgOutput, "table", "Output format: table or json").
+		AddBoolFlag(pconstants.ArgHelp, false, "Help for plugin list", cmdconfig.FlagOptions.WithShortHand("h"))
 	return cmd
 }
 
@@ -215,7 +218,7 @@ Example:
 	}
 
 	cmdconfig.OnCmd(cmd).
-		AddBoolFlag(constants.ArgHelp, false, "Help for plugin uninstall", cmdconfig.FlagOptions.WithShortHand("h"))
+		AddBoolFlag(pconstants.ArgHelp, false, "Help for plugin uninstall", cmdconfig.FlagOptions.WithShortHand("h"))
 
 	return cmd
 }
@@ -248,8 +251,8 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 	// - aws@^0.118
 	// - ghcr.io/turbot/steampipe/plugins/turbot/aws:1.0.0
 	plugins := append([]string{}, args...)
-	showProgress := viper.GetBool(constants.ArgProgress)
-	installReports := make(display.PluginInstallReports, 0, len(plugins))
+	showProgress := viper.GetBool(pconstants.ArgProgress)
+	installReports := make(pplugin.PluginInstallReports, 0, len(plugins))
 
 	if len(plugins) == 0 {
 		if len(steampipeconfig.GlobalConfig.Plugins) == 0 {
@@ -260,7 +263,7 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 
 		// get the list of plugins to install
 		for imageRef := range steampipeconfig.GlobalConfig.Plugins {
-			ref := ociinstaller.NewSteampipeImageRef(imageRef)
+			ref := putils.NewImageRef(imageRef)
 			plugins = append(plugins, ref.GetFriendlyName())
 		}
 	}
@@ -276,7 +279,7 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 	fmt.Println()
 	progressBars := uiprogress.New()
 	installWaitGroup := &sync.WaitGroup{}
-	reportChannel := make(chan *display.PluginInstallReport, len(plugins))
+	reportChannel := make(chan *pplugin.PluginInstallReport, len(plugins))
 
 	if showProgress {
 		progressBars.Start()
@@ -285,17 +288,17 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 		installWaitGroup.Add(1)
 		bar := createProgressBar(pluginName, progressBars)
 
-		ref := ociinstaller.NewSteampipeImageRef(pluginName)
-		org, name, constraint := ref.GetOrgNameAndConstraint()
+		ref := putils.NewImageRef(pluginName)
+		org, name, constraint := ref.GetOrgNameAndStream()
 		orgAndName := fmt.Sprintf("%s/%s", org, name)
-		var resolved plugin.ResolvedPluginVersion
-		if ref.IsFromSteampipeHub() {
-			rpv, err := plugin.GetLatestPluginVersionByConstraint(ctx, state.InstallationID, org, name, constraint)
+		var resolved pplugin.ResolvedPluginVersion
+		if ref.IsFromTurbotHub() {
+			rpv, err := pplugin.GetLatestPluginVersionByConstraint(ctx, state.InstallationID, org, name, constraint)
 			if err != nil || rpv == nil {
-				report := &display.PluginInstallReport{
+				report := &pplugin.PluginInstallReport{
 					Plugin:         pluginName,
 					Skipped:        true,
-					SkipReason:     constants.InstallMessagePluginNotFound,
+					SkipReason:     pconstants.InstallMessagePluginNotFound,
 					IsUpdateReport: false,
 				}
 				reportChannel <- report
@@ -304,7 +307,7 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 			}
 			resolved = *rpv
 		} else {
-			resolved = plugin.NewResolvedPluginVersion(orgAndName, constraint, constraint)
+			resolved = pplugin.NewResolvedPluginVersion(orgAndName, constraint, constraint)
 		}
 
 		go doPluginInstall(ctx, bar, pluginName, resolved, installWaitGroup, reportChannel)
@@ -331,7 +334,7 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 
 		// reload the config, since an installation should have created a new config file
 		var cmd = viper.Get(constants.ConfigKeyActiveCommand).(*cobra.Command)
-		config, errorsAndWarnings := steampipeconfig.LoadSteampipeConfig(ctx, viper.GetString(constants.ArgModLocation), cmd.Name())
+		config, errorsAndWarnings := steampipeconfig.LoadSteampipeConfig(ctx, viper.GetString(pconstants.ArgModLocation), cmd.Name())
 		if errorsAndWarnings.GetError() != nil {
 			error_helpers.ShowWarning(fmt.Sprintf("Failed to reload config - install report may be incomplete (%s)", errorsAndWarnings.GetError()))
 		} else {
@@ -340,35 +343,35 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 
 		statushooks.Done(ctx)
 	}
-	display.PrintInstallReports(installReports, false)
+	pplugin.PrintInstallReports(installReports, false)
 
 	// a concluding blank line - since we always output multiple lines
 	fmt.Println()
 }
 
-func doPluginInstall(ctx context.Context, bar *uiprogress.Bar, pluginName string, resolvedPlugin plugin.ResolvedPluginVersion, wg *sync.WaitGroup, returnChannel chan *display.PluginInstallReport) {
-	var report *display.PluginInstallReport
+func doPluginInstall(ctx context.Context, bar *uiprogress.Bar, pluginName string, resolvedPlugin pplugin.ResolvedPluginVersion, wg *sync.WaitGroup, returnChannel chan *pplugin.PluginInstallReport) {
+	var report *pplugin.PluginInstallReport
 
-	pluginAlreadyInstalled, _ := plugin.Exists(ctx, pluginName)
+	pluginAlreadyInstalled, _ := pplugin.Exists(ctx, pluginName)
 	if pluginAlreadyInstalled {
 		// set the bar to MAX
 		//nolint:golint,errcheck // the error happens if we set this over the max value
 		bar.Set(len(pluginInstallSteps))
 		// let the bar append itself with "Already Installed"
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
-			return helpers.Resize(constants.InstallMessagePluginAlreadyInstalled, 20)
+			return helpers.Resize(pconstants.InstallMessagePluginAlreadyInstalled, 20)
 		})
-		report = &display.PluginInstallReport{
+		report = &pplugin.PluginInstallReport{
 			Plugin:         pluginName,
 			Skipped:        true,
-			SkipReason:     constants.InstallMessagePluginAlreadyInstalled,
+			SkipReason:     pconstants.InstallMessagePluginAlreadyInstalled,
 			IsUpdateReport: false,
 		}
 	} else {
 		// let the bar append itself with the current installation step
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
-			if report != nil && report.SkipReason == constants.InstallMessagePluginNotFound {
-				return helpers.Resize(constants.InstallMessagePluginNotFound, 20)
+			if report != nil && report.SkipReason == pconstants.InstallMessagePluginNotFound {
+				return helpers.Resize(pconstants.InstallMessagePluginNotFound, 20)
 			} else {
 				if b.Current() == 0 {
 					// no install step to display yet
@@ -403,7 +406,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	// - aws@^0.118
 	// - ghcr.io/turbot/steampipe/plugins/turbot/aws:1.0.0
 	plugins, err := resolveUpdatePluginsFromArgs(args)
-	showProgress := viper.GetBool(constants.ArgProgress)
+	showProgress := viper.GetBool(pconstants.ArgProgress)
 
 	if err != nil {
 		fmt.Println()
@@ -415,11 +418,11 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 		return
 	}
 
-	if len(plugins) > 0 && !(cmdconfig.Viper().GetBool(constants.ArgAll)) && plugins[0] == constants.ArgAll {
+	if len(plugins) > 0 && !(cmdconfig.Viper().GetBool(pconstants.ArgAll)) && plugins[0] == pconstants.ArgAll {
 		// improve the response to wrong argument "steampipe plugin update all"
 		fmt.Println()
 		exitCode = constants.ExitCodeInsufficientOrWrongInputs
-		error_helpers.ShowError(ctx, fmt.Errorf("Did you mean %s?", constants.Bold("--all")))
+		error_helpers.ShowError(ctx, fmt.Errorf("Did you mean %s?", pconstants.Bold("--all")))
 		fmt.Println()
 		return
 	}
@@ -435,15 +438,15 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	pluginVersions := steampipeconfig.GlobalConfig.PluginVersions
 
 	var runUpdatesFor []*versionfile.InstalledVersion
-	updateResults := make(display.PluginInstallReports, 0, len(plugins))
+	updateResults := make(pplugin.PluginInstallReports, 0, len(plugins))
 
 	// a leading blank line - since we always output multiple lines
 	fmt.Println()
 
-	if cmdconfig.Viper().GetBool(constants.ArgAll) {
+	if cmdconfig.Viper().GetBool(pconstants.ArgAll) {
 		for k, v := range pluginVersions {
-			ref := ociinstaller.NewSteampipeImageRef(k)
-			org, name, constraint := ref.GetOrgNameAndConstraint()
+			ref := putils.NewImageRef(k)
+			org, name, constraint := ref.GetOrgNameAndStream()
 			key := fmt.Sprintf("%s/%s@%s", org, name, constraint)
 
 			plugins = append(plugins, key)
@@ -452,8 +455,8 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	} else {
 		// get the args and retrieve the installed versions
 		for _, p := range plugins {
-			ref := ociinstaller.NewSteampipeImageRef(p)
-			isExists, _ := plugin.Exists(ctx, p)
+			ref := putils.NewImageRef(p)
+			isExists, _ := pplugin.Exists(ctx, p)
 			if isExists {
 				if strings.HasPrefix(ref.DisplayImageRef(), constants.SteampipeHubOCIBase) {
 					runUpdatesFor = append(runUpdatesFor, pluginVersions[ref.DisplayImageRef()])
@@ -464,10 +467,10 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 				}
 			} else {
 				exitCode = constants.ExitCodePluginNotFound
-				updateResults = append(updateResults, &display.PluginInstallReport{
+				updateResults = append(updateResults, &pplugin.PluginInstallReport{
 					Skipped:        true,
 					Plugin:         p,
-					SkipReason:     constants.InstallMessagePluginNotInstalled,
+					SkipReason:     pconstants.InstallMessagePluginNotInstalled,
 					IsUpdateReport: true,
 				})
 			}
@@ -478,7 +481,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 		// we have report for all
 		// this may happen if all given plugins are
 		// not installed
-		display.PrintInstallReports(updateResults, true)
+		pplugin.PrintInstallReports(updateResults, true)
 		fmt.Println()
 		return
 	}
@@ -487,7 +490,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	defer cancel()
 
 	statushooks.SetStatus(ctx, "Checking for available updates")
-	reports := plugin.GetUpdateReport(timeoutCtx, state.InstallationID, runUpdatesFor)
+	reports := pplugin.GetUpdateReport(timeoutCtx, state.InstallationID, runUpdatesFor)
 	statushooks.Done(ctx)
 	if len(reports) == 0 {
 		// this happens if for some reason the update server could not be contacted,
@@ -498,7 +501,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	}
 
 	updateWaitGroup := &sync.WaitGroup{}
-	reportChannel := make(chan *display.PluginInstallReport, len(reports))
+	reportChannel := make(chan *pplugin.PluginInstallReport, len(reports))
 	progressBars := uiprogress.New()
 	if showProgress {
 		progressBars.Start()
@@ -527,16 +530,16 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 		progressBars.Stop()
 	}
 
-	display.PrintInstallReports(updateResults, true)
+	pplugin.PrintInstallReports(updateResults, true)
 
 	// a concluding blank line - since we always output multiple lines
 	fmt.Println()
 }
 
-func doPluginUpdate(ctx context.Context, bar *uiprogress.Bar, pvr plugin.VersionCheckReport, wg *sync.WaitGroup, returnChannel chan *display.PluginInstallReport) {
-	var report *display.PluginInstallReport
+func doPluginUpdate(ctx context.Context, bar *uiprogress.Bar, pvr pplugin.PluginVersionCheckReport, wg *sync.WaitGroup, returnChannel chan *pplugin.PluginInstallReport) {
+	var report *pplugin.PluginInstallReport
 
-	if plugin.UpdateRequired(pvr) {
+	if pplugin.UpdateRequired(pvr) {
 		// update required, resolve version and install update
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
 			// set the progress bar to append itself  with the step underway
@@ -546,20 +549,20 @@ func doPluginUpdate(ctx context.Context, bar *uiprogress.Bar, pvr plugin.Version
 			}
 			return helpers.Resize(pluginInstallSteps[b.Current()-1], 20)
 		})
-		rp := plugin.NewResolvedPluginVersion(pvr.ShortName(), pvr.CheckResponse.Version, pvr.CheckResponse.Constraint)
+		rp := pplugin.NewResolvedPluginVersion(pvr.ShortName(), pvr.CheckResponse.Version, pvr.CheckResponse.Constraint)
 		report = installPlugin(ctx, rp, true, bar)
 	} else {
 		// update NOT required, return already installed report
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
 			// set the progress bar to append itself with "Already Installed"
-			return helpers.Resize(constants.InstallMessagePluginLatestAlreadyInstalled, 30)
+			return helpers.Resize(pconstants.InstallMessagePluginLatestAlreadyInstalled, 30)
 		})
 		// set the progress bar to the maximum
 		bar.Set(len(pluginInstallSteps))
-		report = &display.PluginInstallReport{
+		report = &pplugin.PluginInstallReport{
 			Plugin:         fmt.Sprintf("%s@%s", pvr.CheckResponse.Name, pvr.CheckResponse.Constraint),
 			Skipped:        true,
-			SkipReason:     constants.InstallMessagePluginLatestAlreadyInstalled,
+			SkipReason:     pconstants.InstallMessagePluginLatestAlreadyInstalled,
 			IsUpdateReport: true,
 		}
 	}
@@ -576,7 +579,7 @@ func createProgressBar(plugin string, parentProgressBars *uiprogress.Progress) *
 	return bar
 }
 
-func installPlugin(ctx context.Context, resolvedPlugin plugin.ResolvedPluginVersion, isUpdate bool, bar *uiprogress.Bar) *display.PluginInstallReport {
+func installPlugin(ctx context.Context, resolvedPlugin pplugin.ResolvedPluginVersion, isUpdate bool, bar *uiprogress.Bar) *pplugin.PluginInstallReport {
 	// start a channel for progress publications from plugin.Install
 	progress := make(chan struct{}, 5)
 	defer func() {
@@ -592,18 +595,18 @@ func installPlugin(ctx context.Context, resolvedPlugin plugin.ResolvedPluginVers
 		}
 	}()
 
-	image, err := plugin.Install(ctx, resolvedPlugin, progress, ociinstaller.WithSkipConfig(viper.GetBool(constants.ArgSkipConfig)))
+	image, err := plugin.Install(ctx, resolvedPlugin, progress, constants.BaseImageRef, ociinstaller.SteampipeMediaTypeProvider{}, putils.WithSkipConfig(viper.GetBool(pconstants.ArgSkipConfig)))
 	if err != nil {
 		msg := ""
 		// used to build data for the plugin install report to be used for display purposes
-		_, name, constraint := ociinstaller.NewSteampipeImageRef(resolvedPlugin.GetVersionTag()).GetOrgNameAndConstraint()
+		_, name, constraint := putils.NewImageRef(resolvedPlugin.GetVersionTag()).GetOrgNameAndStream()
 		if isPluginNotFoundErr(err) {
 			exitCode = constants.ExitCodePluginNotFound
-			msg = constants.InstallMessagePluginNotFound
+			msg = pconstants.InstallMessagePluginNotFound
 		} else {
 			msg = err.Error()
 		}
-		return &display.PluginInstallReport{
+		return &pplugin.PluginInstallReport{
 			Plugin:         fmt.Sprintf("%s@%s", name, constraint),
 			Skipped:        true,
 			SkipReason:     msg,
@@ -612,16 +615,16 @@ func installPlugin(ctx context.Context, resolvedPlugin plugin.ResolvedPluginVers
 	}
 
 	// used to build data for the plugin install report to be used for display purposes
-	org, name, _ := image.ImageRef.GetOrgNameAndConstraint()
+	org, name, _ := image.ImageRef.GetOrgNameAndStream()
 	versionString := ""
 	if image.Config.Plugin.Version != "" {
 		versionString = " v" + image.Config.Plugin.Version
 	}
 	docURL := fmt.Sprintf("https://hub.steampipe.io/plugins/%s/%s", org, name)
-	if !image.ImageRef.IsFromSteampipeHub() {
+	if !image.ImageRef.IsFromTurbotHub() {
 		docURL = fmt.Sprintf("https://%s/%s", org, name)
 	}
-	return &display.PluginInstallReport{
+	return &pplugin.PluginInstallReport{
 		Plugin:         fmt.Sprintf("%s@%s", name, resolvedPlugin.Constraint),
 		Skipped:        false,
 		Version:        versionString,
@@ -639,12 +642,12 @@ func resolveUpdatePluginsFromArgs(args []string) ([]string, error) {
 
 	if len(plugins) == 0 && !(cmdconfig.Viper().GetBool("all")) {
 		// either plugin name(s) or "all" must be provided
-		return nil, fmt.Errorf("you need to provide at least one plugin to update or use the %s flag", constants.Bold("--all"))
+		return nil, fmt.Errorf("you need to provide at least one plugin to update or use the %s flag", pconstants.Bold("--all"))
 	}
 
-	if len(plugins) > 0 && cmdconfig.Viper().GetBool(constants.ArgAll) {
+	if len(plugins) > 0 && cmdconfig.Viper().GetBool(pconstants.ArgAll) {
 		// we can't allow update and install at the same time
-		return nil, fmt.Errorf("%s cannot be used when updating specific plugins", constants.Bold("`--all`"))
+		return nil, fmt.Errorf("%s cannot be used when updating specific plugins", pconstants.Bold("`--all`"))
 	}
 
 	return plugins, nil
@@ -654,7 +657,7 @@ func runPluginListCmd(cmd *cobra.Command, _ []string) {
 	// setup a cancel context and start cancel handler
 	ctx, cancel := context.WithCancel(cmd.Context())
 	contexthelpers.StartCancelHandler(cancel)
-	outputFormat := viper.GetString(constants.ArgOutput)
+	outputFormat := viper.GetString(pconstants.ArgOutput)
 
 	utils.LogTime("runPluginListCmd list")
 	defer func() {
@@ -679,7 +682,7 @@ func runPluginListCmd(cmd *cobra.Command, _ []string) {
 
 }
 
-func showPluginListOutput(pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]*modconfig.Connection, res error_helpers.ErrorAndWarnings, outputFormat string) error {
+func showPluginListOutput(pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]plugin.PluginConnection, res perror_helpers.ErrorAndWarnings, outputFormat string) error {
 	switch outputFormat {
 	case "table":
 		return showPluginListAsTable(pluginList, failedPluginMap, missingPluginMap, res)
@@ -690,7 +693,7 @@ func showPluginListOutput(pluginList []plugin.PluginListItem, failedPluginMap, m
 	}
 }
 
-func showPluginListAsTable(pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]*modconfig.Connection, res error_helpers.ErrorAndWarnings) error {
+func showPluginListAsTable(pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]plugin.PluginConnection, res perror_helpers.ErrorAndWarnings) error {
 	headers := []string{"Installed", "Version", "Connections"}
 	var rows [][]string
 	// List installed plugins in a table
@@ -701,7 +704,7 @@ func showPluginListAsTable(pluginList []plugin.PluginListItem, failedPluginMap,
 	} else {
 		rows = append(rows, []string{"", "", ""})
 	}
-	display.ShowWrappedTable(headers, rows, &display.ShowWrappedTableOptions{AutoMerge: false})
+	querydisplay.ShowWrappedTable(headers, rows, &querydisplay.ShowWrappedTableOptions{AutoMerge: false})
 	fmt.Printf("\n")
 
 	// List failed/missing plugins in a separate table
@@ -713,22 +716,22 @@ func showPluginListAsTable(pluginList []plugin.PluginListItem, failedPluginMap,
 		// failed plugins
 		for p, item := range failedPluginMap {
 			for _, conn := range item {
-				conns = append(conns, conn.Name)
+				conns = append(conns, conn.GetName())
 			}
-			missingRows = append(missingRows, []string{p, strings.Join(conns, ","), constants.ConnectionErrorPluginFailedToStart})
+			missingRows = append(missingRows, []string{p, strings.Join(conns, ","), pconstants.ConnectionErrorPluginFailedToStart})
 			conns = []string{}
 		}
 
 		// missing plugins
 		for p, item := range missingPluginMap {
 			for _, conn := range item {
-				conns = append(conns, conn.Name)
+				conns = append(conns, conn.GetName())
 			}
-			missingRows = append(missingRows, []string{p, strings.Join(conns, ","), constants.InstallMessagePluginNotInstalled})
+			missingRows = append(missingRows, []string{p, strings.Join(conns, ","), pconstants.InstallMessagePluginNotInstalled})
 			conns = []string{}
 		}
 
-		display.ShowWrappedTable(headers, missingRows, &display.ShowWrappedTableOptions{AutoMerge: false})
+		querydisplay.ShowWrappedTable(headers, missingRows, &querydisplay.ShowWrappedTableOptions{AutoMerge: false})
 		fmt.Println()
 	}
 
@@ -740,7 +743,7 @@ func showPluginListAsTable(pluginList []plugin.PluginListItem, failedPluginMap,
 	return nil
 }
 
-func showPluginListAsJSON(pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]*modconfig.Connection, res error_helpers.ErrorAndWarnings) error {
+func showPluginListAsJSON(pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]plugin.PluginConnection, res perror_helpers.ErrorAndWarnings) error {
 	output := pluginJsonOutput{}
 
 	for _, item := range pluginList {
@@ -755,12 +758,12 @@ func showPluginListAsJSON(pluginList []plugin.PluginListItem, failedPluginMap, m
 	for p, item := range failedPluginMap {
 		connections := make([]string, len(item))
 		for i, conn := range item {
-			connections[i] = conn.Name
+			connections[i] = conn.GetName()
 		}
 		failed := failedPlugin{
 			Name:        p,
 			Connections: connections,
-			Reason:      constants.ConnectionErrorPluginFailedToStart,
+			Reason:      pconstants.ConnectionErrorPluginFailedToStart,
 		}
 		output.Failed = append(output.Failed, failed)
 	}
@@ -768,12 +771,12 @@ func showPluginListAsJSON(pluginList []plugin.PluginListItem, failedPluginMap, m
 	for p, item := range missingPluginMap {
 		connections := make([]string, len(item))
 		for i, conn := range item {
-			connections[i] = conn.Name
+			connections[i] = conn.GetName()
 		}
 		missing := failedPlugin{
 			Name:        p,
 			Connections: connections,
-			Reason:      constants.InstallMessagePluginNotInstalled,
+			Reason:      pconstants.InstallMessagePluginNotInstalled,
 		}
 		output.Failed = append(output.Failed, missing)
 	}
@@ -823,7 +826,7 @@ func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
 		return
 	}
 
-	reports := steampipeconfig.PluginRemoveReports{}
+	reports := plugin.PluginRemoveReports{}
 	statushooks.SetStatus(ctx, fmt.Sprintf("Uninstalling %s", utils.Pluralize("plugin", len(args))))
 	for _, p := range args {
 		statushooks.SetStatus(ctx, fmt.Sprintf("Uninstalling %s", p))
@@ -841,7 +844,7 @@ func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
 	reports.Print()
 }
 
-func getPluginList(ctx context.Context) (pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]*modconfig.Connection, res error_helpers.ErrorAndWarnings) {
+func getPluginList(ctx context.Context) (pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]plugin.PluginConnection, res perror_helpers.ErrorAndWarnings) {
 	statushooks.Show(ctx)
 	defer statushooks.Done(ctx)
 
@@ -851,10 +854,13 @@ func getPluginList(ctx context.Context) (pluginList []plugin.PluginListItem, fai
 		return nil, nil, nil, res
 	}
 
+	// retrieve the plugin version data from steampipe config
+	pluginVersions := steampipeconfig.GlobalConfig.PluginVersions
+
 	// TODO do we really need to look at installed plugins - can't we just use the plugin connection map
 	// get a list of the installed plugins by inspecting the install location
 	// pass pluginConnectionMap so we can populate the connections for each plugin
-	pluginList, err := plugin.List(ctx, pluginConnectionMap)
+	pluginList, err := plugin.List(ctx, pluginConnectionMap, pluginVersions)
 	if err != nil {
 		res.Error = err
 		return nil, nil, nil, res
@@ -872,13 +878,13 @@ func getPluginList(ctx context.Context) (pluginList []plugin.PluginListItem, fai
 	return pluginList, failedPluginMap, missingPluginMap, res
 }
 
-func getPluginConnectionMap(ctx context.Context) (pluginConnectionMap, failedPluginMap, missingPluginMap map[string][]*modconfig.Connection, res error_helpers.ErrorAndWarnings) {
+func getPluginConnectionMap(ctx context.Context) (pluginConnectionMap, failedPluginMap, missingPluginMap map[string][]plugin.PluginConnection, res perror_helpers.ErrorAndWarnings) {
 	utils.LogTime("cmd.getPluginConnectionMap start")
 	defer utils.LogTime("cmd.getPluginConnectionMap end")
 
 	statushooks.SetStatus(ctx, "Fetching connection map")
 
-	res = error_helpers.ErrorAndWarnings{}
+	res = perror_helpers.ErrorAndWarnings{}
 
 	connectionStateMap, stateRes := getConnectionState(ctx)
 	res.Merge(stateRes)
@@ -887,9 +893,9 @@ func getPluginConnectionMap(ctx context.Context) (pluginConnectionMap, failedPlu
 	}
 
 	// create the map of failed/missing plugins and available/loaded plugins
-	failedPluginMap = map[string][]*modconfig.Connection{}
-	missingPluginMap = map[string][]*modconfig.Connection{}
-	pluginConnectionMap = make(map[string][]*modconfig.Connection)
+	failedPluginMap = map[string][]plugin.PluginConnection{}
+	missingPluginMap = map[string][]plugin.PluginConnection{}
+	pluginConnectionMap = make(map[string][]plugin.PluginConnection)
 
 	for _, state := range connectionStateMap {
 		connection, ok := steampipeconfig.GlobalConfig.Connections[state.ConnectionName]
@@ -897,9 +903,9 @@ func getPluginConnectionMap(ctx context.Context) (pluginConnectionMap, failedPlu
 			continue
 		}
 
-		if state.State == constants.ConnectionStateError && state.Error() == constants.ConnectionErrorPluginFailedToStart {
+		if state.State == constants.ConnectionStateError && state.Error() == pconstants.ConnectionErrorPluginFailedToStart {
 			failedPluginMap[state.Plugin] = append(failedPluginMap[state.Plugin], connection)
-		} else if state.State == constants.ConnectionStateError && state.Error() == constants.ConnectionErrorPluginNotInstalled {
+		} else if state.State == constants.ConnectionStateError && state.Error() == pconstants.ConnectionErrorPluginNotInstalled {
 			missingPluginMap[state.Plugin] = append(missingPluginMap[state.Plugin], connection)
 		}
 
@@ -910,12 +916,12 @@ func getPluginConnectionMap(ctx context.Context) (pluginConnectionMap, failedPlu
 }
 
 // load the connection state, waiting until all connections are loaded
-func getConnectionState(ctx context.Context) (steampipeconfig.ConnectionStateMap, error_helpers.ErrorAndWarnings) {
+func getConnectionState(ctx context.Context) (steampipeconfig.ConnectionStateMap, perror_helpers.ErrorAndWarnings) {
 	utils.LogTime("cmd.getConnectionState start")
 	defer utils.LogTime("cmd.getConnectionState end")
 
 	// start service
-	client, res := db_local.GetLocalClient(ctx, constants.InvokerPlugin, nil)
+	client, res := db_local.GetLocalClient(ctx, constants.InvokerPlugin)
 	if res.Error != nil {
 		return nil, res
 	}
