@@ -12,10 +12,11 @@ import (
 	"github.com/hashicorp/go-version"
 	_ "github.com/jackc/pgx/v5/stdlib"
 	"github.com/turbot/go-kit/helpers"
+	"github.com/turbot/pipe-fittings/utils"
 	"github.com/turbot/steampipe/cmd"
+	"github.com/turbot/steampipe/pkg/cmdconfig"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/error_helpers"
-	"github.com/turbot/steampipe/pkg/utils"
 )
 
 var exitCode int = constants.ExitCodeSuccessful
@@ -44,6 +45,8 @@ func main() {
 	// check OSX kernel version
 	checkOSXVersion(ctx)
 
+	cmdconfig.SetAppSpecificConstants()
+
 	cmd.InitCmd()
 
 	// execute the command
