@@ -3,19 +3,20 @@ package cmdconfig
 import (
 	"context"
 	"fmt"
+	"strings"
+
 	"github.com/spf13/viper"
 	filehelpers "github.com/turbot/go-kit/files"
-	"github.com/turbot/steampipe/pkg/cloud"
-	"github.com/turbot/steampipe/pkg/constants"
+	pconstants "github.com/turbot/pipe-fittings/constants"
+	"github.com/turbot/pipe-fittings/pipes"
+	"github.com/turbot/pipe-fittings/steampipeconfig"
 	"github.com/turbot/steampipe/pkg/error_helpers"
-	"github.com/turbot/steampipe/pkg/steampipeconfig"
-	"strings"
 )
 
 func ValidateSnapshotArgs(ctx context.Context) error {
 	// only 1 of 'share' and 'snapshot' may be set
-	share := viper.GetBool(constants.ArgShare)
-	snapshot := viper.GetBool(constants.ArgSnapshot)
+	share := viper.GetBool(pconstants.ArgShare)
+	snapshot := viper.GetBool(pconstants.ArgSnapshot)
 	if share && snapshot {
 		return fmt.Errorf("only 1 of 'share' and 'snapshot' may be set")
 	}
@@ -25,7 +26,7 @@ func ValidateSnapshotArgs(ctx context.Context) error {
 		return nil
 	}
 
-	token := viper.GetString(constants.ArgPipesToken)
+	token := viper.GetString(pconstants.ArgPipesToken)
 
 	// determine whether snapshot location is a cloud workspace or a file location
 	// if a file location, check it exists
@@ -34,8 +35,8 @@ func ValidateSnapshotArgs(ctx context.Context) error {
 	}
 
 	// if workspace-database or snapshot-location are a cloud workspace handle, cloud token must be set
-	requireCloudToken := steampipeconfig.IsCloudWorkspaceIdentifier(viper.GetString(constants.ArgWorkspaceDatabase)) ||
-		steampipeconfig.IsCloudWorkspaceIdentifier(viper.GetString(constants.ArgSnapshotLocation))
+	requireCloudToken := steampipeconfig.IsPipesWorkspaceIdentifier(viper.GetString(pconstants.ArgWorkspaceDatabase)) ||
+		steampipeconfig.IsPipesWorkspaceIdentifier(viper.GetString(pconstants.ArgSnapshotLocation))
 
 	// verify cloud token and workspace has been set
 	if requireCloudToken && token == "" {
@@ -43,7 +44,7 @@ func ValidateSnapshotArgs(ctx context.Context) error {
 	}
 
 	// should never happen as there is a default set
-	if viper.GetString(constants.ArgPipesHost) == "" {
+	if viper.GetString(pconstants.ArgPipesHost) == "" {
 		return fmt.Errorf("to share snapshots, cloud host must be set")
 	}
 
@@ -51,7 +52,7 @@ func ValidateSnapshotArgs(ctx context.Context) error {
 }
 
 func validateSnapshotLocation(ctx context.Context, cloudToken string) error {
-	snapshotLocation := viper.GetString(constants.ArgSnapshotLocation)
+	snapshotLocation := viper.GetString(pconstants.ArgSnapshotLocation)
 
 	// if snapshot location is not set, set to the users default
 	if snapshotLocation == "" {
@@ -63,7 +64,7 @@ func validateSnapshotLocation(ctx context.Context, cloudToken string) error {
 
 	// if it is NOT a workspace handle, assume it is a local file location:
 	// tildefy it and ensure it exists
-	if !steampipeconfig.IsCloudWorkspaceIdentifier(snapshotLocation) {
+	if !steampipeconfig.IsPipesWorkspaceIdentifier(snapshotLocation) {
 		var err error
 		snapshotLocation, err = filehelpers.Tildefy(snapshotLocation)
 		if err != nil {
@@ -71,7 +72,7 @@ func validateSnapshotLocation(ctx context.Context, cloudToken string) error {
 		}
 
 		// write back to viper
-		viper.Set(constants.ArgSnapshotLocation, snapshotLocation)
+		viper.Set(pconstants.ArgSnapshotLocation, snapshotLocation)
 
 		if !filehelpers.DirectoryExists(snapshotLocation) {
 			return fmt.Errorf("snapshot location %s does not exist", snapshotLocation)
@@ -81,20 +82,20 @@ func validateSnapshotLocation(ctx context.Context, cloudToken string) error {
 }
 
 func setSnapshotLocationFromDefaultWorkspace(ctx context.Context, cloudToken string) error {
-	workspaceHandle, err := cloud.GetUserWorkspaceHandle(ctx, cloudToken)
+	workspaceHandle, err := pipes.GetUserWorkspaceHandle(ctx, cloudToken)
 	if err != nil {
 		return err
 	}
 
-	viper.Set(constants.ArgSnapshotLocation, workspaceHandle)
+	viper.Set(pconstants.ArgSnapshotLocation, workspaceHandle)
 	return nil
 }
 
 func validateSnapshotTags() error {
-	tags := viper.GetStringSlice(constants.ArgSnapshotTag)
+	tags := viper.GetStringSlice(pconstants.ArgSnapshotTag)
 	for _, tagStr := range tags {
 		if len(strings.Split(tagStr, "=")) != 2 {
-			return fmt.Errorf("snapshot tags must be specified '--%s key=value'", constants.ArgSnapshotTag)
+			return fmt.Errorf("snapshot tags must be specified '--%s key=value'", pconstants.ArgSnapshotTag)
 		}
 	}
 	return nil
