@@ -2,16 +2,17 @@ package connection
 
 import (
 	"context"
+
 	"github.com/jackc/pgx/v5/pgxpool"
+	"github.com/turbot/pipe-fittings/error_helpers"
+	"github.com/turbot/pipe-fittings/plugin"
 	"github.com/turbot/steampipe-plugin-sdk/v5/grpc/proto"
-	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/shared"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
 type pluginManager interface {
 	shared.PluginManager
-	OnConnectionConfigChanged(context.Context, ConnectionConfigMap, map[string]*modconfig.Plugin)
+	OnConnectionConfigChanged(context.Context, ConnectionConfigMap, map[string]*plugin.Plugin)
 	GetConnectionConfig() ConnectionConfigMap
 	HandlePluginLimiterChanges(PluginLimiterMap) error
 	Pool() *pgxpool.Pool
