@@ -9,8 +9,8 @@ import (
 	"time"
 
 	"github.com/spf13/viper"
+	pconstants "github.com/turbot/pipe-fittings/constants"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
-	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
 )
 
@@ -37,17 +37,17 @@ func cacheControl(ctx context.Context, input *HandlerInput) error {
 	conn := sessionResult.Session.Connection.Conn()
 	command := strings.ToLower(input.args()[0])
 	switch command {
-	case constants.ArgOn:
+	case pconstants.ArgOn:
 		serverSettings := input.Client.ServerSettings()
 		if serverSettings != nil && !serverSettings.CacheEnabled {
 			fmt.Println("Caching is disabled on the server.")
 		}
-		viper.Set(constants.ArgClientCacheEnabled, true)
+		viper.Set(pconstants.ArgClientCacheEnabled, true)
 		return db_common.SetCacheEnabled(ctx, true, conn)
-	case constants.ArgOff:
-		viper.Set(constants.ArgClientCacheEnabled, false)
+	case pconstants.ArgOff:
+		viper.Set(pconstants.ArgClientCacheEnabled, false)
 		return db_common.SetCacheEnabled(ctx, false, conn)
-	case constants.ArgClear:
+	case pconstants.ArgClear:
 		return db_common.CacheClear(ctx, conn)
 	}
 
@@ -77,7 +77,7 @@ func cacheTTL(ctx context.Context, input *HandlerInput) error {
 		// we need to do this in a closure, otherwise the ctx will be evaluated immediately
 		// and not in call-time
 		sessionResult.Session.Close(false)
-		viper.Set(constants.ArgCacheTtl, seconds)
+		viper.Set(pconstants.ArgCacheTtl, seconds)
 	}()
 	return db_common.SetCacheTtl(ctx, time.Duration(seconds)*time.Second, sessionResult.Session.Connection.Conn())
 }
@@ -91,16 +91,16 @@ func showCache(_ context.Context, input *HandlerInput) error {
 	currentStatusString := "off"
 	action := "on"
 
-	if !viper.IsSet(constants.ArgClientCacheEnabled) || viper.GetBool(constants.ArgClientCacheEnabled) {
+	if !viper.IsSet(pconstants.ArgClientCacheEnabled) || viper.GetBool(pconstants.ArgClientCacheEnabled) {
 		currentStatusString = "on"
 		action = "off"
 	}
 
 	fmt.Printf(
 		`Caching is %s. To turn it %s, type %s`,
-		constants.Bold(currentStatusString),
-		constants.Bold(action),
-		constants.Bold(fmt.Sprintf(".cache %s", action)),
+		pconstants.Bold(currentStatusString),
+		pconstants.Bold(action),
+		pconstants.Bold(fmt.Sprintf(".cache %s", action)),
 	)
 
 	// add an empty line here so that the rendering buffer can start from the next line
@@ -110,8 +110,8 @@ func showCache(_ context.Context, input *HandlerInput) error {
 }
 
 func showCacheTtl(ctx context.Context, input *HandlerInput) error {
-	if viper.IsSet(constants.ArgCacheTtl) {
-		ttl := getEffectiveCacheTtl(input.Client.ServerSettings(), viper.GetInt(constants.ArgCacheTtl))
+	if viper.IsSet(pconstants.ArgCacheTtl) {
+		ttl := getEffectiveCacheTtl(input.Client.ServerSettings(), viper.GetInt(pconstants.ArgCacheTtl))
 		fmt.Println("Cache TTL is", ttl, "seconds.")
 	} else if input.Client.ServerSettings() != nil {
 		serverTtl := input.Client.ServerSettings().CacheMaxTtl
