@@ -3,9 +3,9 @@ package introspection
 import (
 	"fmt"
 
+	"github.com/turbot/pipe-fittings/plugin"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
 func GetPluginTableCreateSql() db_common.QueryWithArgs {
@@ -23,7 +23,7 @@ func GetPluginTableCreateSql() db_common.QueryWithArgs {
 	}
 }
 
-func GetPluginTablePopulateSql(plugin *modconfig.Plugin) db_common.QueryWithArgs {
+func GetPluginTablePopulateSql(plugin *plugin.Plugin) db_common.QueryWithArgs {
 	return db_common.QueryWithArgs{
 		Query: fmt.Sprintf(`INSERT INTO %s.%s (
 plugin,
