@@ -1,7 +1,7 @@
 package steampipeconfig
 
 import (
-	"github.com/turbot/steampipe/pkg/error_helpers"
+	"github.com/turbot/pipe-fittings/error_helpers"
 )
 
 const PostgresNotificationStructVersion = 20230306
